.. _bfg_sql_wiki_tutorial:

SQLAlchemy + URL Dispatch Wiki Tutorial
=======================================

This tutorial introduces a :term:`SQLAlchemy` and :term:`url dispatch` -based
:app:`Pyramid` application to a developer familiar with Python, and will be
most familiar to developers who have used the :term:`Pylons` 1.X web
framework.  When the tutorial is finished, the developer will have created a
basic Wiki application with authentication.

For cut and paste purposes, the source code for all stages of this
tutorial can be browsed at
`http://github.com/Pylons/pyramid/tree/master/docs/tutorials/wiki2/src/
<http://github.com/Pylons/pyramid/tree/master/docs/tutorials/wiki2/src/>`_.

.. toctree::
   :maxdepth: 2

   background
   installation
   basiclayout
   definingmodels
   definingviews
   authorization
   tests
   distributing


